@@ -19,6 +19,7 @@ import unittest
 from google.api_core import exceptions
 import google.api_core.retry
 import mock
+import pytest
 
 from .helpers import _make_client
 from .helpers import _make_connection
@@ -250,7 +251,7 @@ class Test_AsyncJob(unittest.TestCase):
         labels = {"foo": "bar"}
         client = _make_client(project=self.PROJECT)
         job = self._make_one(self.JOB_ID, client)
-        job._properties["labels"] = labels
+        job._properties.setdefault("configuration", {})["labels"] = labels
         self.assertEqual(job.labels, labels)
 
     def test_etag(self):
@@ -1021,6 +1022,12 @@ class Test_JobConfig(unittest.TestCase):
         self.assertEqual(job_config._job_type, self.JOB_TYPE)
         self.assertEqual(job_config._properties, {self.JOB_TYPE: {}})
 
+    def test_ctor_with_unknown_property_raises_error(self):
+        error_text = "Property wrong_name is unknown for"
+        with pytest.raises(AttributeError, match=error_text):
+            config = self._make_one()
+            config.wrong_name = None
+
     def test_fill_from_default(self):
         from google.cloud.bigquery import QueryJobConfig
 
